@@ -44,36 +44,35 @@
 (defvar ai-code-kiro-cli--processes (make-hash-table :test 'equal)
   "Hash table mapping Kiro session keys to processes.")
 
-(defun ai-code-kiro-cli--build-args ()
-  "Build the Kiro CLI argument list."
-  (let ((args (list "chat")))
+(defun ai-code-kiro-cli--build-command ()
+  "Build the Kiro CLI command string."
+  (let ((args (list ai-code-kiro-cli-program "chat")))
     (when ai-code-kiro-cli-trust-all-tools
       (setq args (append args '("--trust-all-tools"))))
     (when ai-code-kiro-cli-agent
       (setq args (append args (list "--agent" ai-code-kiro-cli-agent))))
     (when ai-code-kiro-cli-program-switches
       (setq args (append args ai-code-kiro-cli-program-switches)))
-    args))
-
-(defun ai-code-kiro-cli--build-command ()
-  "Build the Kiro CLI command string."
-  (mapconcat 'identity
-             (cons ai-code-kiro-cli-program (ai-code-kiro-cli--build-args))
-             " "))
+    (mapconcat 'identity args " ")))
 
 ;;;###autoload
 (defun ai-code-kiro-cli (&optional arg)
   "Start Kiro CLI chat session.
-With prefix ARG, prompt for CLI args using the current defaults
-(chat, agent, trust flags, and `ai-code-kiro-cli-program-switches')."
+With prefix ARG, prompt for a new instance name."
   (interactive "P")
   (let* ((working-dir (ai-code-backends-infra--session-working-directory))
-         (resolved (ai-code-backends-infra--resolve-start-command
-                    ai-code-kiro-cli-program
-                    (ai-code-kiro-cli--build-args)
-                    arg
-                    "Kiro"))
-         (command (plist-get resolved :command)))
+         (force-prompt (and arg t))
+         (command (ai-code-kiro-cli--build-command))
+         (instance-name nil))
+    (unless force-prompt
+      (when-let ((existing-buffer
+                  (ai-code-backends-infra--select-session-buffer
+                   ai-code-kiro-cli--session-prefix
+                   working-dir)))
+        (setq instance-name
+              (ai-code-backends-infra--session-instance-name
+               (buffer-name existing-buffer)
+               ai-code-kiro-cli--session-prefix))))
     (ai-code-backends-infra--toggle-or-create-session
      working-dir
      nil
@@ -81,9 +80,9 @@ With prefix ARG, prompt for CLI args using the current defaults
      command
      #'ai-code-kiro-cli-send-escape
      nil
-     nil
+     instance-name
      ai-code-kiro-cli--session-prefix
-     nil)))
+     force-prompt)))
 
 ;;;###autoload
 (defun ai-code-kiro-cli-switch-to-buffer (&optional force-prompt)
